@@ -18,6 +18,8 @@ from mw_python_sdk.llm.model import (
     Role2,
     ServiceTier1,
     Logprobs2,
+    TopLogprob,
+    ChatCompletionTokenLogprob,
     ChatCompletionStreamResponseDelta,
     CompletionUsage,
 )
@@ -113,7 +115,19 @@ async def chat_completions(request: CreateChatCompletionRequest):
                     refusal="",
                     function_call=None,
                 ),
-                logprobs=Logprobs2(content=[], refusal=[]),
+                logprobs=Logprobs2(
+                    content=[
+                        ChatCompletionTokenLogprob(
+                            token="As",
+                            logprob=-0.1,
+                            bytes=[2],
+                            top_logprobs=[
+                                TopLogprob(token="As", logprob=-0.1, bytes=[2])
+                            ],
+                        )
+                    ],
+                    refusal=[],
+                ),
                 finish_reason=FinishReason1.length,
             )
         ],
